/// <reference types="react" />
import * as PropTypes from 'prop-types';
import * as React from 'react';
import { Component } from 'react';
import { ImageProperties } from 'react-native';
export interface IFitImageProps extends ImageProperties {
    /**
     * Whether should display activity indicator or not
     */
    indicator?: boolean;
    /**
     * Color of activity indicator in string
     */
    indicatorColor?: string;
    /**
     * Size of activity indicator
     */
    indicatorSize?: 'small' | 'large' | number;
    /**
     * Original height of the image
     *
     * @description
     * If you already know the height of the image you can pass it here.
     * Then it will be used instead of fetching the size information remotely.
     */
    originalHeight?: number;
    /**
     * Original width of the image
     *
     * @description
     * If you already know the width of the image you can pass it here.
     * Then it will be used instead of fetching the size information remotely.
     */
    originalWidth?: number;
}
export interface IFitImageState {
    height: number;
    isLoading: boolean;
    layoutWidth: number | undefined;
    originalHeight: number | undefined;
    originalWidth: number | undefined;
}
declare class FitImage extends Component<IFitImageProps, IFitImageState> {
    static propTypes: {
        indicator: PropTypes.Requireable<any>;
        indicatorColor: PropTypes.Requireable<any>;
        indicatorSize: PropTypes.Requireable<any>;
        originalHeight: PropTypes.Requireable<any>;
        originalWidth: PropTypes.Requireable<any>;
    } | {
        indicator: PropTypes.Requireable<any>;
        indicatorColor: PropTypes.Requireable<any>;
        indicatorSize: PropTypes.Requireable<any>;
        originalHeight: PropTypes.Requireable<any>;
        originalWidth: PropTypes.Requireable<any>;
        onLayout?: React.Validator<ImageProperties> | undefined;
        onError?: React.Validator<ImageProperties> | undefined;
        onLoad?: React.Validator<ImageProperties> | undefined;
        onLoadEnd?: React.Validator<ImageProperties> | undefined;
        onLoadStart?: React.Validator<ImageProperties> | undefined;
        progressiveRenderingEnabled?: React.Validator<ImageProperties> | undefined;
        resizeMode?: React.Validator<ImageProperties> | undefined;
        resizeMethod?: React.Validator<ImageProperties> | undefined;
        source?: React.Validator<ImageProperties> | undefined;
        loadingIndicatorSource?: React.Validator<ImageProperties> | undefined;
        style?: React.Validator<ImageProperties> | undefined;
        testID?: React.Validator<ImageProperties> | undefined;
        accessibilityLabel?: React.Validator<ImageProperties> | undefined;
        accessible?: React.Validator<ImageProperties> | undefined;
        blurRadius?: React.Validator<ImageProperties> | undefined;
        capInsets?: React.Validator<ImageProperties> | undefined;
        defaultSource?: React.Validator<ImageProperties> | undefined;
        onProgress?: React.Validator<ImageProperties> | undefined;
        onPartialLoad?: React.Validator<ImageProperties> | undefined;
    };
    private style;
    private isFirstLoad;
    private mounted;
    constructor(props: IFitImageProps);
    componentDidMount(): void;
    componentWillUnmount(): void;
    render(): JSX.Element;
    private onLoad;
    private onLoadStart;
    private getHeight;
    private getOriginalHeight;
    private getOriginalWidth;
    private getRatio;
    private getStyle;
    private resize;
    private refreshStateSize;
    private setStateSize;
    private renderActivityIndicator;
}
export default FitImage;
